      subroutine printWC(rho_0,mom_0,dir,centSide, rhoWC_min,rhoWC_max, 
     &     labelLgth,label)
      implicit none
c
c     This subroutine saves the (rho,mom)-plane projection 
c     of the wave-curve centered at (rho_0, mom_0) state
c     in files with label-based names.
c     There are N1 points in the curve. The wave-curve is computed for 
c     rho \in [rhoWC_min, rhoWC_max].
c
c-----------------------------------------------------------------------
c                              INPUT 
c-----------------------------------------------------------------------
c
c     STATE at which the wave-curve is CENTERED
c     -----------------------------------------
c  rho_0    density
c  mom_0    momentum
c
c  dir =1 for right-facing wave, =-1 for left-facing wave
c  centSide =  -1 STATE at which the wave-curve is CENTERED is BEHIND
c              +1 STATE at which the wave-curve is CENTERED is AHEAD
c   
c--------------------------------------------------------------------------
c                             AUXILIARY 
c--------------------------------------------------------------------------
c
c       STATE on the WAVE-CURVE 
c       -----------------------
c    rho  density
c    mom  momentum
c
      include 'input_output.h'
      include 'wave_constants.h'

c     Input:
      real*8 rho_0,mom_0, rhoWC_min,rhoWC_max
      integer dir,centSide
      integer labelLgth
      character*80 label
c     Auxiliary:
      integer i,N1
      parameter (N1=1001)
      real*8 drho, rho, mom, onWaveCurve, st2inv
      external rho2momExpan,rho2momCompr
      real*8 rho2momExpan,rho2momCompr
c-----

      open(fid_rm,file='rm_curv_' // label(1:labelLgth) // '.dat')
      write(fid_rm,1000) rho_0, mom_0
      write(fid_rm,*) '&'

      open(fid_iLiR,file='iLiR_curv_' // label(1:labelLgth) // '.dat')
      write(fid_iLiR,1000) 
     &     st2inv(rho_0,mom_0,DIR_L), st2inv(rho_0,mom_0,DIR_R) 
      write(fid_iLiR,*) '&'

      drho  = (rhoWC_max-rhoWC_min)/(N1-1)
      do i=1,N1
         rho=rhoWC_min+(i-1)*drho
         mom=onWaveCurve(rho,rho_0,mom_0,dir,centSide,
     &        rho2momExpan,rho2momCompr)
         write(fid_rm,1000) rho, mom
         write(fid_iLiR,1000) 
     &        st2inv(rho,mom,DIR_L), st2inv(rho,mom,DIR_R)
      enddo
      write(fid_rm,*) '&'
      close(fid_rm)
      write(fid_iLiR,*) '&'
      close(fid_iLiR)

 1000 format(f26.8,5x,f26.8)

      end
