      subroutine riemann(
     &     rho_l0,mom_l0,rho_r0,mom_r0,labelLgth,label,
     &     rho_0,mom_0,w_0,signif_0,wave_type_0)
      implicit none
c
c-----------------------------------------------------------------------
c                              INPUT 
c-----------------------------------------------------------------------
c
c    LEFT STATE VARIABLES
c    --------------------
c  rho_l0    density
c  mom_l0    momentum
c
c    RIGHT STATE VARIABLES
c    ---------------------
c  rho_r0    density
c  mom_r0    momentum
c
c-------------------------------------------------------------------------
c                            OUTPUT 
c-------------------------------------------------------------------------
c
c          STATE VARIABLES
c          ---------------
c    rho_0(1:N_STATES)   density
c    mom_0(1:N_STATES)   momentum
c     1 - Left (Init.) State;  
c     2 - Middle State;
c     3 - Right (Init.) State;
c
c    NOTE: Left (initial) State  EQUALS Left  state of INPUT
c          Right (initial) State EQUALS Right state of INPUT
c
c         WAVE STRUCTURE 
c         --------------
c    1 - left-facing outer wave; 
c    2 - right-facing outer wave
c
c    wave_type_0(1:N_WAVES) -- type of the wave
c     = RFN  rarefaction fan
c     = SFR  shock front
c
c    signif_0(1:N_WAVES) =1 if the wave is signigicant; =0 otherwise
c       THIS INFORMATION IS GIVEN FOR WAVE TRACKING PURPOSES: 
c       signif_0(i) = 1: i-th wave should be tracked
c       signif_0(i) = 0: i-th wave should not be tracked
c
c    EACH WAVE CAN BE EITHER A RAREFACTION FAN OR A SHARP FRONT.  
c    THE FOLLOWING CONVENTION IS USED: 
c    A SHARP FRONT IS DESCRIBED AS A FAN WHOSE EDGES COINCIDE.
c
c    w_0(1:N_EDGES)    velocities of the fan-edges:
c        w_0(1) = velocity of the outer  edge of the left-f fan
c        w_0(2) = velocity of the innner edge of the left-f fan
c        w_0(3) = velocity of the inner  edge of the right-f fan
c        w_0(4) = velocity of the outer  edge of the right-f fan
c
c
c--------------------------------------------------------------------------
c                             AUXILIARY 
c--------------------------------------------------------------------------
c
c    MIDDLE STATE VARIABLES returned by subroutine newton:
c    ----------------------
c    rho    density
c    mom    momentum
c
      include 'parameters.h'
      include 'wave_constants.h'
      include 'input_output.h'

c     Input:
      real*8 rho_l0,mom_l0,rho_r0,mom_r0
      integer labelLgth
      character*80 label
c     Output:
      real*8  rho_0(N_STATES),mom_0(N_STATES),w_0(N_EDGES)
      integer signif_0(N_WAVES),wave_type_0(N_WAVES)
c     Auxiliary:
      real*8 rho,mom
      real*8 rhoWC_min,rhoWC_max
      integer labelLeLgth,labelRiLgth
      character*80 labelLe,labelRi

      if (PRINT_WC) then
         rhoWC_min = rho_min
         rhoWC_max = 20.d0*rho_l0
         labelLe = 'l_' // label(1:labelLgth)
         labelLeLgth = labelLgth+2
         call printWC(rho_l0,mom_l0,DIR_L,AHEAD,
     &        rhoWC_min,rhoWC_max,labelLeLgth,labelLe)

         rhoWC_min = rho_min
         rhoWC_max = 20.d0*rho_r0
         labelRi = 'r_' // label(1:labelLgth)
         labelRiLgth = labelLgth+2
         call printWC(rho_r0,mom_r0,DIR_R,AHEAD,
     &        rhoWC_min,rhoWC_max,labelRiLgth,labelRi)
      endif

      call newton(rho_l0,mom_l0,rho_r0,mom_r0,labelLgth,label,rho,mom)

      call states(rho_l0,mom_l0,rho,mom,rho_r0,mom_r0,
     &     rho_0,mom_0,w_0,signif_0,wave_type_0)

      if (PRINT_RP) then
         call rpOut
     &        (rho_0,mom_0,w_0,signif_0,wave_type_0,labelLgth,label)
      endif
      
      end
